@@ -347,27 +347,25 @@ process_lookup_symbol (Process *process, gulong address)
     
 /*     g_print ("addr: %x\n", address); */
     
-    if (!map)
+    if (address == 0x1)
     {
-	if (address == 0x1)
-	{
-	    kernel.name = "in kernel";
-	    kernel.address = 0x0001337;
-	    return &kernel;
-	}
-	else
-	{
-	    if (undefined.name)
-		g_free (undefined.name);
-	    undefined.name = g_strdup_printf ("??? %s", process->cmdline);
-	    undefined.address = 0xBABE0001;
-	}
+	kernel.name = "in kernel";
+	kernel.address = 0x0001337;
+	return &kernel;
+    }
+    else if (!map)
+    {
+	if (undefined.name)
+	    g_free (undefined.name);
+	undefined.name = g_strdup_printf ("??? %s", process->cmdline);
+	undefined.address = 0xBABE0001;
+
 #if 0
 	g_print ("no map for %p (%s)\n", address, process->cmdline);
 #endif
-	
 	return &undefined;
     }
+    
 #if 0
     g_print ("has map: %s\n", process->cmdline);
 #endif
